#!/bin/bash


function print_log() {
    echo -e "\033[32mINFO:     "$1" \033[0m"
}

function print_error() {
    echo -e "\033[31mERROR:     "$1" \033[0m"
}

# check if python existed
PYTHON_VERSION=$(python -V)
if [ $? != 0 ]; then
  print_error "python does not existed. you need install python (3.5 or above) first."
  exit 127
fi

# check python version
MINIMUM_PY_VERSION=35
PY_VERSION=$(echo "$PYTHON_VERSION"|awk '{print $2}'|awk -F '.' '{print $1$2}')
if [[ "$PY_VERSION" -lt $MINIMUM_PY_VERSION ]]; then
    print_error "Your python version doesn't met the requirement, which requires python "$MINIMUM_PY_VERSION" or above."
    print_error "Exit with code 1"
    exit 1
else
    print_log  "Python version ("$PY_VERSION") check success."
fi

# install requirements
if [ -e requirements.txt ]; then
    print_log "Installing requirements"
    pip install -r requirements.txt
else
    print_error "requirements.txt does not existed."
    print_error "Exit with code 2"
    exit  2
fi

print_log "Starting web server."
python main.py
